BoundMutator

Trait BoundMutator 

pub trait BoundMutator:
    Sized
    + Copy
    + Debug {
    // Required method
    fn bound(
        self,
        min: Self,
        max: Self,
        test_runner: &mut TestRunner,
    ) -> Option<Self>;
}
Mutator that bounds the current value of an uint or int in the given range. The mutated value is always different from the current value.

Required Methods

fn bound( self, min: Self, max: Self, test_runner: &mut TestRunner, ) -> Option<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BoundMutator for Uint<256, 4>

Source

fn bound( self, min: Uint<256, 4>, max: Uint<256, 4>, test_runner: &mut TestRunner, ) -> Option<Uint<256, 4>>

Implementors

Source

impl BoundMutator for Signed<256, 4>